@@ -43,11 +43,11 @@ def any(
             result as dimensions with size one. With this option, the result
             will broadcast correctly against the input array.
 
-    Returns:
+    Return:
         A new boolean or `ndarray` is returned unless `out` is specified,
         in which case a reference to `out` is returned.
 
-    Examples:
+    Example:
         >>> q0 = numpoly.variable()
         >>> numpoly.any(q0)
         True
