@@ -41,11 +41,11 @@ def ceil(
         kwargs:
             Keyword args passed to numpy.ufunc.
 
-    Returns:
+    Return:
         The ceiling of each element in `x`, with `float` dtype.
         This is a scalar if `x` is a scalar.
 
-    Examples:
+    Example:
         >>> q0 = numpoly.variable()
         >>> numpoly.ceil([-1.7*q0, q0-1.5, -0.2,
         ...               3.2+1.5*q0, 1.7, 2.0])
@@ -57,5 +57,5 @@ def ceil(
         inputs=(q0,),
         out=None if out is None else (out,),
         where=where,
-        **kwargs
+        **kwargs,
     )
