@@ -44,10 +44,10 @@ def full_like(
             dimensions is unchanged, will try to keep order, otherwise,
             order='C' is implied.
 
-    Returns:
+    Return:
         Array of `fill_value` with the same shape and type as `a`.
 
-    Examples:
+    Example:
         >>> poly = numpoly.monomial(3)
         >>> poly
         polynomial([1, q0, q0**2])
