@@ -42,11 +42,11 @@ def multiply(
         kwargs:
             Keyword args passed to numpy.ufunc.
 
-    Returns:
+    Return:
         The product of `x1` and `x2`, element-wise. This is a scalar if
         both `x1` and `x2` are scalars.
 
-    Examples:
+    Example:
         >>> poly = numpy.arange(9.0).reshape((3, 3))
         >>> q0q1q2 = numpoly.variable(3)
         >>> numpoly.multiply(poly, q0q1q2)
@@ -61,26 +61,34 @@ def multiply(
 
     where = numpy.asarray(where)
     exponents = numpy.unique(
-        numpy.tile(x1.exponents, (len(x2.exponents), 1)) +
-        numpy.repeat(x2.exponents, len(x1.exponents), 0), axis=0)
-    out_ = numpoly.ndpoly(
-        exponents=exponents,
-        shape=shape,
-        names=x1.indeterminants,
-        dtype=dtype,
-    ) if out is None else out
+        numpy.tile(x1.exponents, (len(x2.exponents), 1))
+        + numpy.repeat(x2.exponents, len(x1.exponents), 0),
+        axis=0,
+    )
+    out_ = (
+        numpoly.ndpoly(
+            exponents=exponents,
+            shape=shape,
+            names=x1.indeterminants,
+            dtype=dtype,
+        )
+        if out is None
+        else out
+    )
 
     seen = set()
     for expon1, coeff1 in zip(x1.exponents, x1.coefficients):
         for expon2, coeff2 in zip(x2.exponents, x2.coefficients):
-            key = (expon1+expon2+x1.KEY_OFFSET).ravel()
+            key = (expon1 + expon2 + x1.KEY_OFFSET).ravel()
             key = key.view(f"U{len(expon1)}").item()
             if key in seen:
                 out_.values[key] += numpy.multiply(
-                    coeff1, coeff2, where=where, **kwargs)
+                    coeff1, coeff2, where=where, **kwargs
+                )
             else:
-                numpy.multiply(coeff1, coeff2, out=out_.values[key],
-                               where=where, **kwargs)
+                numpy.multiply(
+                    coeff1, coeff2, out=out_.values[key], where=where, **kwargs
+                )
             seen.add(key)
 
     if out is None:
