@@ -2,7 +2,10 @@
 from .polynomial import polynomial
 from .aspolynomial import aspolynomial
 from .clean import (
-    clean_attributes, remove_redundant_coefficients, remove_redundant_names)
+    clean_attributes,
+    remove_redundant_coefficients,
+    remove_redundant_names,
+)
 from .from_attributes import polynomial_from_attributes
 from .from_roots import polynomial_from_roots
 from .monomial import monomial
