@@ -16,11 +16,11 @@ def to_sympy(poly: PolyLike) -> Any:
         poly:
             Polynomial object to convert to sympy.
 
-    Returns:
+    Return:
         If scalar, a sympy expression object, or if array, numpy.array with
         expression object values.
 
-    Examples:
+    Example:
         >>> q0, q1 = numpoly.variable(2)
         >>> poly = numpoly.polynomial([[1, q0**3], [q1-1, -3*q0]])
         >>> sympy_poly = to_sympy(poly)
@@ -35,6 +35,7 @@ def to_sympy(poly: PolyLike) -> Any:
     if poly.shape:
         return numpy.array([to_sympy(poly_) for poly_ in poly])
     from sympy import symbols  # type: ignore
+
     locals_ = dict(zip(poly.names, symbols(poly.names)))
     polynomial = eval(str(poly), locals_, {})  # pylint: disable=eval-used
     return polynomial
