@@ -10,12 +10,12 @@ from .glexsort import glexsort
 
 
 def glexindex(
-        start: numpy.typing.ArrayLike,
-        stop: Optional[numpy.typing.ArrayLike] = None,
-        dimensions: int = 1,
-        cross_truncation: numpy.typing.ArrayLike = 1.,
-        graded: bool = False,
-        reverse: bool = False,
+    start: numpy.typing.ArrayLike,
+    stop: Optional[numpy.typing.ArrayLike] = None,
+    dimensions: int = 1,
+    cross_truncation: numpy.typing.ArrayLike = 1.0,
+    graded: bool = False,
+    reverse: bool = False,
 ) -> numpy.ndarray:
     """
     Generate graded lexicographical multi-indices for the monomial exponents.
@@ -43,11 +43,11 @@ def glexindex(
             Reversed lexicographical sorting meaning that ``(1, 3)`` is
             considered smaller than ``(3, 1)``, instead of the opposite.
 
-    Returns:
+    Return:
         list:
             Order list of indices.
 
-    Examples:
+    Example:
         >>> numpoly.glexindex(4).tolist()
         [[0], [1], [2], [3]]
         >>> numpoly.glexindex(2, dimensions=2).tolist()
@@ -66,7 +66,7 @@ def glexindex(
     stop = numpy.array(stop, dtype=int).flatten()
     start, stop, _ = numpy.broadcast_arrays(start, stop, numpy.empty(dimensions))
 
-    cross_truncation = cross_truncation*numpy.ones(2)
+    cross_truncation = cross_truncation * numpy.ones(2)
     indices = _glexindex(start, stop, cross_truncation)
 
     if indices.size:
@@ -74,7 +74,7 @@ def glexindex(
     return indices
 
 
-def _glexindex(start, stop, cross_truncation=1.):
+def _glexindex(start, stop, cross_truncation=1.0):
     """Backend for the glexindex function."""
     # At the beginning the current list of indices just ranges over the
     # last dimension.
@@ -85,11 +85,11 @@ def _glexindex(start, stop, cross_truncation=1.):
     range_ = numpy.arange(bound, dtype=dtype)
     indices = range_[:, numpy.newaxis]
 
-    for idx in range(dimensions-1):
+    for idx in range(dimensions - 1):
 
         # Truncate at each step to keep memory usage low
         if idx:
-            indices = indices[cross_truncate(indices, bound-1, cross_truncation[1])]
+            indices = indices[cross_truncate(indices, bound - 1, cross_truncation[1])]
 
         # Repeats the current set of indices.
         # e.g. [0,1,2] -> [0,1,2,0,1,2,...,0,1,2]
@@ -97,7 +97,7 @@ def _glexindex(start, stop, cross_truncation=1.):
 
         # Stretches ranges over the new dimension.
         # e.g. [0,1,2] -> [0,0,...,0,1,1,...,1,2,2,...,2]
-        front = range_.repeat(len(indices)//bound)[:, numpy.newaxis]
+        front = range_.repeat(len(indices) // bound)[:, numpy.newaxis]
 
         # Puts them two together.
         indices = numpy.column_stack((front, indices))
@@ -106,8 +106,8 @@ def _glexindex(start, stop, cross_truncation=1.):
     if dimensions == 1:
         indices = indices[(indices >= start) & (indices < bound)]
     else:
-        lower = cross_truncate(indices, start-1, cross_truncation[0])
-        upper = cross_truncate(indices, stop-1, cross_truncation[1])
-        indices = indices[lower^upper]
+        lower = cross_truncate(indices, start - 1, cross_truncation[0])
+        upper = cross_truncate(indices, stop - 1, cross_truncation[1])
+        indices = indices[lower ^ upper]
 
     return numpy.array(indices, dtype=int).reshape(-1, dimensions)
